/*============================================================*/
/*============================================================*/
/*==														==*/
/*==				QuickDraw Rendering Header				==*/
/*==														==*/
/*============================================================*/
/*============================================================*/


/*========================================================  Prototypes  */

void RenderSceneQD1 (void);
void RenderSceneQDC (void);
void DisplayScoreDigitQD1 (short, short, short);
void DisplayScoreDigitQDC (short, short, short);
void DisplayPlayerFoulsQD1 (short);
void DisplayPlayerFoulsQDC (short);
void DisplayOpponentFoulsQD1 (short);
void DisplayOpponentFoulsQDC (short);
void TwinkleAStarQD1 (short);
void TwinkleAStarQDC (short, short);
void DrawOffscreenAStarQD1 (short);
void DrawOffscreenAStarQDC (short, short);
void UpdateArrowsQD1 (void);
void UpdateArrowsQDC (void);
void RedrawWholeScreen (void);
void ReplayBackToWorkQD1 (void);
void ReplayBackToWorkQDC (void);
void ReplayWorkToMainQD1 (void);
void ReplayWorkToMainQDC (void);
Boolean DumpPict (short);
void UpdateBallTimersQD1 (Rect *);
void UpdateBallTimersQDC (Rect *);


/*========================================================  External Variables */

extern playerType	thePlayer;
extern playerType	theOpponent;
extern ballType		theBall;
extern doorType		theDoor;
extern digiDispType	scoreDisplays[2];
extern replayType	*replayData;
extern RGBColor		RGBBlackColor;
extern RGBColor		starColors[3];
extern WindowPtr	mainWndo;
extern GrafPtr		offBackPtr, offWorkPtr;
extern GrafPtr		offMaskPort;
extern BitMap		offBackBits, offPartsBits, offWorkBits;
extern BitMap		offMaskMap;
extern CGrafPort	offCBackPort, offCPartsPort, offCWorkPort;
extern CGrafPtr		offCBackPtr, offCPartsPtr, offCWorkPtr;
extern Rect			offBackRect, offPartsRect, offWorkRect, offMaskRect;
extern Rect			replayRect, cameraRect, colonDest;
extern Rect			leftArrowSrc, rightArrowSrc, leftArrowDest, rightArrowDest;
extern Rect			leftArrowStorage, rightArrowStorage, timingSource;
extern Rect			playerSrcRects[9][3], fadeMaskRects[9][3], opponentSrcRects[9][3];
extern Rect			colonSrc[2];
extern Point		starList[kNumberOfStars];
extern short		displayMode, screenWide, screenHigh, whosGotBall;
extern short		playerFouls, opponentFouls;
extern Boolean		leftGoalIsPlayers, playerInBack, playerJustScored, isColor;
extern Boolean		drawThisFrame, showBoardCursor;
